#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%bcond_with test
%endif
Name:           python-flaky%{?psuffix}
Version:        3.7.0
Release:        4.1
Summary:        Plugin for nose or py.test that automatically reruns flaky tests
License:        Apache-2.0
URL:            https://github.com/box/flaky
Source:         https://files.pythonhosted.org/packages/source/f/flaky/flaky-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM remove_nose.patch gh#box/flaky#171 mcepl@suse.com
# remove dependency on nose
Patch0:         remove_nose.patch
# PATCH-FEATURE-UPSTREAM remove_mock.patch gh#box/flaky!197 mcepl@suse.com
# remove dependency on the external mock package
Patch1:         remove_mock.patch
# PATCH-FEATURE-UPSTREAM remove_genty.patch gh#box/flaky!197 mcepl@suse.com
# remove dependency on the external genty package
Patch2:         remove_genty.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module flaky >= %{version}}
BuildRequires:  %{python_module pytest}
%if 0%{?suse_version} <= 1500
BuildRequires:  python-mock
%endif
%endif
%python_subpackages

%description
Flaky is a plugin for py.test that automatically reruns flaky tests.

Ideally, tests reliably pass or fail, but sometimes test fixtures must rely on components that aren't 100%
reliable. With flaky, instead of removing those tests or marking them to @skip, they can be automatically
retried.

For more information about flaky, see `this presentation <http://opensource.box.com/flaky/>`_.

%prep
%autosetup -p1 -n flaky-%{version}

%if !%{with test}
%build
%python_build
%endif

%if !%{with test}
%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest -k 'example and not options' --doctest-modules test/test_pytest/
%pytest -k 'example and not options' test/test_pytest/
%pytest -p no:flaky test/test_pytest/test_flaky_pytest_plugin.py
export PYTEST_ADDOPTS="--force-flaky --max-runs 2"
%pytest test/test_pytest/test_pytest_options_example.py
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/flaky
%{python_sitelib}/flaky-%{version}*-info
%endif

%changelog
* Fri Oct 20 2023 Matej Cepl <mcepl@cepl.eu>
- Add remove_genty.patch to remove dependency on the external
  genty package (gh#box/flaky!197).
* Fri Oct 20 2023 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- Fix condition around BuildRequirement
* Sun Dec 13 2020 Matej Cepl <mcepl@suse.com>
- We don't need to break Python 2.7
* Fri Dec 11 2020 Matej Cepl <mcepl@suse.com>
- Add remove_mock.patch to remove dependency on the external mock package.
* Fri Dec 11 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove dependency on nose.
* Wed Jul 29 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.7.0:
  * Flaky now retries tests which fail during setup.
* Fri Jan 31 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add required suffix to package name for test package. Although
  no binary package is created, the OBS blocks any dependent
  packages until also the test package has been built (Giveaway:
  main and test flavor create the same .src.rpm)
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.6.1:
  * Reraise KeyboardInterrupt when running tests under pytest.
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 3.6.0
  * Do not print an empty report if no tests marked 'flaky' were run at all (#116). NOTE: This change could be breaking if you relied on the flaky report being printed.
- test via multibuild
- added sources
  + _multibuild
* Tue Mar 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.5.3:
  * Bugfixes - Flaky is now compatible with pytest >= 4.1.
  * Officially support and test on Python 3.6 and 3.7.
  * Adds a pytest marker that can be used instead of `@flaky.
  * Replaced references to 'slaveoutput', where possible with 'workeroutput', following the convention chosen by pytest.
  * Prints formatted tracebacks in the flaky report when using nose.
* Thu Nov  9 2017 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.4.0:
  * Bugfixes - Flaky for pytest will no longer silently swallow errors
    that occur during test setup.
* Tue Dec 20 2016 jmatejek@suse.com
- initial commit
